@@ -9,12 +9,11 @@
 #' @param RR Relative risk between the confounder and the outcome.
 #' @param OR Odds ratio between the confounder and the outcome.
 #' @param crude.RR Crude relative risk between the exposure and the outcome.
-#' @param dec Number of decimals in the printout.
-#' @param print A logical scalar. Should the results be printed?
-#' 
+#'
 #' @return A list with elements:
-#' \item{conf.limits}{Limits on confounding.}
-#' \item{bias.parms}{Input bias parameters p, RR, OR, and crude RR.}
+#' \item{model}{Bias analysis performed.}
+#' \item{bias.parms}{Input bias parameters.}
+#' \item{adj.measures}{Output results.}
 #'
 #' @references
 #' Lash, T.L., Fox, M.P, Fink, A.K., 2009 \emph{Applying Quantitative
@@ -23,16 +22,14 @@
 #' Flanders, W. Dana, Khoury, Muin J., 1990. Indirect Assessment of
 #' Confounding: Graphic Description and Limits on Effect of Adjusting for
 #' Covariates. \emph{Epidemiology} 1(3): 239--246.
-#' 
+#'
 #' @examples
 #' confounders.limit(OR = 1.65, crude.RR = 1.5)
 #' @export
 confounders.limit <- function(p = NA,
                               RR = NA,
                               OR = NA,
-                              crude.RR = NULL,
-                              dec = 4,
-                              print = TRUE){
+                              crude.RR = NULL) {
     if(is.null(crude.RR))
         stop('Please provide crude relative risk.')
     if(is.na(p) & is.na(RR) & is.na(OR))
@@ -43,17 +40,20 @@ confounders.limit <- function(p = NA,
         min(RR, OR, 1/p, RR/(q+RR*p), OR/(q+OR*p), na.rm = TRUE)
     upper.bound <- crude.RR
 
-    if (print)
-        cat("\nLimits on adjusted RR:", round(lower.bound, dec),
-            "<= RRadj <=", round(upper.bound, dec), "\n")
-    if (print)
-        cat("\nInput Bias Parameters:",
-            "\n----------------\n\n")
-    if (print)
-        cat("  p(Confounder+|Exposure-):", p,
-            "\n    RR(Confounder-Disease):", RR,
-            "\n   OR(Confounder-Exposure):", OR,
-            "\nCrude RR(Exposure-Disease):", crude.RR, "\n")
-    invisible(list(conf.limits = c(lower.bound, upper.bound),
-                   bias.parms = c(p, RR, OR, crude.RR)))
+    rmatc <- cbind(lower.bound, upper.bound)
+    rownames(rmatc) <- "Limits on adjusted RR:"
+    colnames(rmatc) <- c("Lower bound", "Upper bound")
+
+    bias.parms <- matrix(c(p, RR, OR, crude.RR))
+    colnames(bias.parms) <- " "
+    rownames(bias.parms) <- c("p(Confounder+|Exposure-):",
+                              "RR(Confounder-Disease):",
+                              "OR(Confounder-Exposure):",
+                              "Crude RR(Exposure-Disease):")
+
+    res <- list(model = "confounder",
+                bias.parms = bias.parms,
+                adj.measures = rmatc)
+    class(res) <- c("episensr.confounder", "episensr", "list")
+    res
 }
