@@ -3,7 +3,7 @@
 #' Print associations for episensr objects.
 #'
 #' @param x An object of class 'episensr'.
-#' @param digits Minimal number of _significant_ digits, see 'print.default'. 
+#' @param digits Minimal number of _significant_ digits, see 'print.default'.
 #' @param ... Other unused arguments.
 #'
 #' @return Print the observed and adjusted measures of association.
@@ -30,5 +30,11 @@ print.episensr <- function(x, digits = getOption("digits"), ...) {
         cat("\n--E-value--\n")
         print.table(x, digits = digits, ...)
         invisible(NULL)
+    } else if (class(x)[1] == "episensr.confounder") {
+        cat("--Input bias parameters--\n")
+        print.table(x$bias.parms, digits = digits, ...)
+        cat("---\n\n")
+        print.table(x$adj.measures, digits = digits, ...)
+        invisible(NULL)
     }
 }
